@@ -43,7 +43,6 @@ type Source struct {
 	ignoreRepos     []string
 	git             *git.Git
 	scanOptions     *git.ScanOptions
-	aCtx            context.Context
 	resumeInfoSlice []string
 	resumeInfoMutex sync.Mutex
 	jobSem          *semaphore.Weighted
@@ -68,9 +67,8 @@ func (s *Source) JobID() int64 {
 }
 
 // Init returns an initialized Gitlab source.
-func (s *Source) Init(aCtx context.Context, name string, jobId, sourceId int64, verify bool, connection *anypb.Any, concurrency int) error {
+func (s *Source) Init(_ context.Context, name string, jobId, sourceId int64, verify bool, connection *anypb.Any, concurrency int) error {
 
-	s.aCtx = aCtx
 	s.name = name
 	s.sourceId = sourceId
 	s.jobId = jobId
